@@ -1,6 +1,6 @@
 /*
  * Carla Bridge UI
- * Copyright (C) 2011-2017 Filipe Coelho <falktx@falktx.com>
+ * Copyright (C) 2011-2021 Filipe Coelho <falktx@falktx.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -55,27 +55,29 @@ protected:
 
     // ---------------------------------------------------------------------
 
-    bool libOpen(const char* const filename) noexcept;
-    void* libSymbol(const char* const symbol) const noexcept;
+    bool libOpen(const char* filename) noexcept;
+    void* libSymbol(const char* symbol) const noexcept;
     const char* libError() const noexcept;
 
     // ---------------------------------------------------------------------
     // DSP Callbacks
 
-    virtual void dspParameterChanged(const uint32_t index, const float value) = 0;
-    virtual void dspProgramChanged(const uint32_t index) = 0;
-    virtual void dspMidiProgramChanged(const uint32_t bank, const uint32_t program) = 0;
-    virtual void dspStateChanged(const char* const key, const char* const value) = 0;
-    virtual void dspNoteReceived(const bool onOff, const uint8_t channel, const uint8_t note, const uint8_t velocity) = 0;
+    virtual void dspParameterChanged(uint32_t index, float value) = 0;
+    virtual void dspParameterChanged(const char* uri, float value) = 0;
+    virtual void dspProgramChanged(uint32_t index) = 0;
+    virtual void dspMidiProgramChanged(uint32_t bank, uint32_t program) = 0;
+    virtual void dspStateChanged(const char* key, const char* value) = 0;
+    virtual void dspNoteReceived(bool onOff, uint8_t channel, uint8_t note, uint8_t velocity) = 0;
 
-    virtual void dspAtomReceived(const uint32_t index, const LV2_Atom* const atom) = 0;
-    virtual void dspURIDReceived(const LV2_URID urid, const char* const uri) = 0;
+    virtual void dspAtomReceived(uint32_t index, const LV2_Atom* atom) = 0;
+    virtual void dspURIDReceived(LV2_URID urid, const char* uri) = 0;
 
     struct BridgeFormatOptions {
         double sampleRate;
         uint32_t bgColor;
         uint32_t fgColor;
         float uiScale;
+        bool isStandalone;
         bool useTheme;
         bool useThemeColors;
         const char* windowTitle;
@@ -88,8 +90,8 @@ public:
     // ---------------------------------------------------------------------
     // UI initialization
 
-    virtual bool init(const int argc, const char* argv[]);
-    virtual void exec(const bool showUI);
+    virtual bool init(int argc, const char* argv[]);
+    virtual void exec(bool showUI);
     virtual void idleUI() {}
 
     // ---------------------------------------------------------------------
@@ -104,12 +106,17 @@ public:
     /*!
      * TESTING
      */
-    virtual void uiResized(const uint width, const uint height) = 0;
+    virtual void uiResized(uint width, uint height) = 0;
 
     /*!
      * Options.
      */
     struct Options {
+        /*!
+         * UI is standalone, not controlled by another application.
+         */
+        bool isStandalone;
+
         /*!
          * UI is resizable by the user.
          * The UI can still sometimes resize itself internally if this is false.
@@ -141,7 +148,8 @@ public:
          * Constructor for default options.
          */
         Options() noexcept
-            : isResizable(true),
+            : isStandalone(true),
+              isResizable(true),
               useTheme(true),
               useThemeColors(true),
               windowTitle("TestUI"),
@@ -166,7 +174,7 @@ protected:
     std::vector<uint8_t> fBase64ReservedChunk;
 
     /*! @internal */
-    bool msgReceived(const char* const msg) noexcept override;
+    bool msgReceived(const char* msg) noexcept override;
 
     CARLA_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR(CarlaBridgeFormat)
 };
