@@ -71,7 +71,7 @@ if WINDOWS:
 # ------------------------------------------------------------------------------------------------------------
 # Set Version
 
-VERSION = "2.3.1"
+VERSION = "2.3.2"
 
 # ------------------------------------------------------------------------------------------------------------
 # Set TMP
@@ -468,7 +468,7 @@ else:
     DEFAULT_VST3_PATH   += ":/usr/local/lib/vst3"
 
     DEFAULT_SF2_PATH     = HOME + "/.sounds/sf2"
-    DEFAULT_SF2_PATH    += HOME + "/.sounds/sf3"
+    DEFAULT_SF2_PATH    += HOME + ":/.sounds/sf3"
     DEFAULT_SF2_PATH    += ":/usr/share/sounds/sf2"
     DEFAULT_SF2_PATH    += ":/usr/share/sounds/sf3"
     DEFAULT_SF2_PATH    += ":/usr/share/soundfonts"
@@ -671,7 +671,8 @@ def handleInitialCommandLineArguments(file):
             print("")
             print("    --cnprefix\t Set a prefix for client names in multi-client mode.")
             if isinstance(gCarla.nogui, bool):
-                print("    --gdb     \t Run Carla inside gdb.")
+                if X_LIBDIR_X is not None:
+                    print("    --gdb     \t Run Carla inside gdb.")
                 print(" -n,--no-gui  \t Run Carla headless, don't show UI.")
                 print("")
             print(" -h,--help    \t Print this help text and exit.")
